@@ -5,7 +5,7 @@ import click
 
 from anyrepo import AnyRepo
 
-from .options import groups_option, output_option
+from .options import groups_option, manifest_option, output_option
 from .util import exceptionhandling, pass_context
 
 
@@ -17,17 +17,18 @@ def manifest():
 
 
 @manifest.command()
+@manifest_option()
 @groups_option()
 @output_option()
 @pass_context
-def resolve(context, groups=None, output=None):
+def resolve(context, manifest_path=None, groups=None, output=None):
     """
     Print The Manifest With All Imports Resolved.
 
     The output is a single manifest file with all dependencies and their dependencies.
     """
     with exceptionhandling(context):
-        anyrepo = AnyRepo.from_path()
+        anyrepo = AnyRepo.from_path(manifest_path=manifest_path)
         manifest = anyrepo.get_manifest_spec(groups=groups, resolve=True)
         if output:
             manifest.save(Path(output))
@@ -36,10 +37,11 @@ def resolve(context, groups=None, output=None):
 
 
 @manifest.command()
+@manifest_option()
 @groups_option()
 @output_option()
 @pass_context
-def freeze(context, groups=None, output=None):
+def freeze(context, manifest_path=None, groups=None, output=None):
     """
     Print The Resolved Manifest With SHAs For All Project Revisions.
 
@@ -47,7 +49,7 @@ def freeze(context, groups=None, output=None):
     Revisions are replaced by the actual SHAs.
     """
     with exceptionhandling(context):
-        anyrepo = AnyRepo.from_path()
+        anyrepo = AnyRepo.from_path(manifest_path=manifest_path)
         manifest = anyrepo.get_manifest_spec(groups=groups, freeze=True, resolve=True)
         if output:
             manifest.save(Path(output))
@@ -56,34 +58,37 @@ def freeze(context, groups=None, output=None):
 
 
 @manifest.command()
+@manifest_option()
 @pass_context
-def validate(context):
+def validate(context, manifest_path=None):
     """
     Validate The Current Manifest, Exiting With An Error On Issues.
     """
     with exceptionhandling(context):
-        AnyRepo.from_path()
+        AnyRepo.from_path(manifest_path=manifest_path)
 
 
 @manifest.command()
+@manifest_option()
 @pass_context
-def path(context):
+def path(context, manifest_path=None):
     """
     Print Path to Main Manifest File.
     """
     with exceptionhandling(context):
-        anyrepo = AnyRepo.from_path()
+        anyrepo = AnyRepo.from_path(manifest_path=manifest_path)
         manifest = next(anyrepo.manifests())
         click.echo(str(manifest.path))
 
 
 @manifest.command()
+@manifest_option()
 @pass_context
-def paths(context):
+def paths(context, manifest_path=None):
     """
     Print Paths to ALL Manifest Files.
     """
     with exceptionhandling(context):
-        anyrepo = AnyRepo.from_path()
+        anyrepo = AnyRepo.from_path(manifest_path=manifest_path)
         for manifest in anyrepo.manifests():
             click.echo(str(manifest.path))
